#
# spec file for package python-pyzo
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-pyzo
Version:        4.11.2
Release:        1.17
Summary:        Python IDE for scientific computing
License:        BSD-3-Clause
URL:            https://github.com/pyzo/pyzo
Source:         https://files.pythonhosted.org/packages/source/p/pyzo/pyzo-%{version}.tar.gz
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       hicolor-icon-theme
Requires:       python-qt5
Requires:       pyzologo
BuildArch:      noarch
%python_subpackages

%description
Pyzo is a computing environment based on Python. Pyzo is a Python IDE
aimed at interactivity, and consists of an editor, a shell, and a set
of tools.

%package     -n pyzo
Summary:        Python IDE for scientific computing
Requires:       python3-pyzo = %{version}

%description -n pyzo
Pyzo is a computing environment based on Python. Pyzo is a Python IDE
aimed at interactivity, and consists of an editor, a shell, and a set
of tools.

%package     -n pyzologo
Summary:        Icons for Pyzo

%description -n pyzologo
Icons used by pyzo

%prep
%setup -q -n pyzo-%{version}
sed -i -e '/^#!\//, 1d' pyzo/*.py
sed -i -e '/^#!\//, 1d' pyzo/codeeditor/_test.py
sed -i -e '/^#!\//, 1d' pyzo/pyzokernel/guisupport.py

%build
%python_build

%install
%python_install
pushd pyzo/resources/
%suse_update_desktop_file pyzo Development Science IDE NumericalAnalysis
install -m 644 -Dt %{buildroot}%{_datadir}/applications pyzo.desktop
popd

pushd pyzo/resources/appicons
for f in pyzologo*.png ; do
    echo ${f}
    r="$(basename ${f:8} .png)"
    echo ${r}
    install -m 644 -Dt %{buildroot}%{_datadir}/icons/hicolor/${r}x${r}/apps/pyzologo.png ${f}
done

popd

%python_expand %fdupes %{buildroot}%{$python_sitelib}

# weirdly installed stuff
rm %{buildroot}%{_prefix}/LICENSE.md
rm %{buildroot}%{_prefix}/README.md
mv %{buildroot}%{_prefix}/pyzo* %{buildroot}%{python_sitelib}/pyzo/util/
chmod +x %{buildroot}%{python_sitelib}/pyzo/util/pyzolauncher.py

%check
# the only test which is in the upstream testsuite
# no need to download github tarball just because of this
export PYTHONPATH=%{buildroot}%{$python_sitelib}
%python_exec -c 'import pyzo; assert pyzo.__version__'

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/*

%files -n pyzo
%license LICENSE.md
%{_datadir}/applications/pyzo.desktop
%{_bindir}/pyzo

%files -n pyzologo
%{_datadir}/icons/hicolor/*/apps/pyzologo.png

%changelog
* Sat May  1 2021 Dirk Müller <dmueller@suse.com>
- update to 4.11.2:
  * Fix for MacOS Big Sur
  * Version 4.11.0
  * Fix broken support for non-english keyboard layouts.
  * Support for Python 3.9
  * Fix slow font enumeration.
  * Improve behavior on HiDPI screens.
  * Prevent errors during editing syntax styles.
  * Change the base port number that Pyzo uses to communicate with the kernels.
  * Remove button to stop kernel but leave the shell open, to reduce clutter.
  * Added support for toggling comments
  * Prevent segfault on PySide2.
  * Pyzo now closes faster.
  * Better handling of carriage return in shell
  * Autocompletion is triggered a bit later to make it less anoying
* Wed Jul 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 4.10.2
  * Fix that PyInstaller's changes to `LD_LIBRARY_PATH` leak through to the kernels (#665).
  * We've now automized the building of binaries on Azure Pipelines!
  * Our code is now formatted with Black, and checked with Flake8.
  * CI does not have a lot of tests yet, but we do check linting and importing on Python 3.5 and 3.8.
  * Implemented support for highres displays (although I am unable to verify myself).
  * Improve the workspace display of list, tuple, dict and array.
  * Clean up `LD_LIBRARY_PATH` for the kernels (#665).
  * Some improvements to asyncio integration.
  * Autocompletion no longer cancels the interactive help.
  * Issue a warning when `logging.basicConfig()` is called (because it does nothing).
  * Fix that non-breakable space was converted (#621, thanks Yann Salmon).
  * Add Jetbrains monospace font.
  * Fix introspection of signature containing kw-only args or annotations.
  * Add polish translation (thanks wojnilowicz)
  * Fix that Pyzo crashes on startup when non-english language is set and status bar is shown.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only removal
* Tue Jan  8 2019 Todd R <toddrme2178@gmail.com>
- initial version
